Synapse.Orchestrator.AgentFactory (Synapse v0.1.1)

Lightweight factory responsible for turning validated %AgentConfig{} definitions into running processes.

Dynamic agents subscribe to the router topics defined in their configuration and execute the configured actions when signals are received.

Summary

Functions

spawn(config, router, registry)

@spec spawn(Synapse.Orchestrator.AgentConfig.t(), atom() | nil, atom() | nil) ::
  {:ok, pid()} | {:error, term()}

stop(pid)

@spec stop(pid()) :: :ok