Synapse.Orchestrator.AgentFactory (Synapse v0.1.1)
View SourceLightweight factory responsible for turning validated %AgentConfig{}
definitions into running processes.
Dynamic agents subscribe to the router topics defined in their configuration and execute the configured actions when signals are received.